@@ -1,5 +1,5 @@
-"Plotntile" <-
-function(path.mcmc,printit=FALSE,file=NULL)
+`Plotntile` <-
+function(path.mcmc,printit=FALSE,file)
   {
     fileparam <- paste(path.mcmc,"parameters.txt",sep="/")
     param <- as.matrix(read.table(fileparam))
